==> jc-1.4.0.tar.gz: java/rmi/AlreadyBoundException.h <==
// public class java.rmi.AlreadyBoundException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f52e63319b0b214f java_rmi_AlreadyBoundException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_AlreadyBoundException_H_
#define _JC_java_rmi_AlreadyBoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_AlreadyBoundException$sub_refs	_jc_java_rmi_AlreadyBoundException$sub_refs;
typedef struct _jc_java_rmi_AlreadyBoundException$sub_nonrefs	_jc_java_rmi_AlreadyBoundException$sub_nonrefs;
typedef struct _jc_java_rmi_AlreadyBoundException$refs	_jc_java_rmi_AlreadyBoundException$refs;
typedef struct _jc_java_rmi_AlreadyBoundException$nonrefs	_jc_java_rmi_AlreadyBoundException$nonrefs;
typedef struct _jc_java_rmi_AlreadyBoundException$object	_jc_java_rmi_AlreadyBoundException$object;

typedef struct _jc_java_rmi_AlreadyBoundException$fields_struct	_jc_java_rmi_AlreadyBoundException$fields_struct;
typedef const struct _jc_java_rmi_AlreadyBoundException$vmethods	_jc_java_rmi_AlreadyBoundException$vmethods;
typedef const struct _jc_java_rmi_AlreadyBoundException$vtable	_jc_java_rmi_AlreadyBoundException$vtable;
typedef const struct _jc_java_rmi_AlreadyBoundException$vtype	_jc_java_rmi_AlreadyBoundException$vtype;

// Class fields structure
struct _jc_java_rmi_AlreadyBoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_AlreadyBoundException$fields_struct _jc_java_rmi_AlreadyBoundException$class_fields;

// Constructors
extern void _jc_java_rmi_AlreadyBoundException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_AlreadyBoundException$object *);
extern void _jc_java_rmi_AlreadyBoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_AlreadyBoundException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_AlreadyBoundException$vmethods {
};

// Vtable
struct _jc_java_rmi_AlreadyBoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_AlreadyBoundException$vmethods	java_rmi_AlreadyBoundException;
};

// Vtype
struct _jc_java_rmi_AlreadyBoundException$vtype {
	_jc_type			type;
	_jc_java_rmi_AlreadyBoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_AlreadyBoundException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_AlreadyBoundException$refs {
    _jc_java_rmi_AlreadyBoundException$sub_refs	java_rmi_AlreadyBoundException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_AlreadyBoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_AlreadyBoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_AlreadyBoundException$sub_nonrefs	java_rmi_AlreadyBoundException;
};

// Object instance structure
struct _jc_java_rmi_AlreadyBoundException$object {
	_jc_java_rmi_AlreadyBoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_AlreadyBoundException$vtype	*vtype;
	_jc_java_rmi_AlreadyBoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_AlreadyBoundException$vtype _jc_java_rmi_AlreadyBoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_AlreadyBoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_AlreadyBoundException$class_object;

#endif	/* _JC_java_rmi_AlreadyBoundException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/AlreadyBoundException.h <==
// public class java.rmi.AlreadyBoundException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f52e63319b0b214f java_rmi_AlreadyBoundException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_AlreadyBoundException_H_
#define _JC_java_rmi_AlreadyBoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_AlreadyBoundException$sub_refs	_jc_java_rmi_AlreadyBoundException$sub_refs;
typedef struct _jc_java_rmi_AlreadyBoundException$sub_nonrefs	_jc_java_rmi_AlreadyBoundException$sub_nonrefs;
typedef struct _jc_java_rmi_AlreadyBoundException$refs	_jc_java_rmi_AlreadyBoundException$refs;
typedef struct _jc_java_rmi_AlreadyBoundException$nonrefs	_jc_java_rmi_AlreadyBoundException$nonrefs;
typedef struct _jc_java_rmi_AlreadyBoundException$object	_jc_java_rmi_AlreadyBoundException$object;

typedef struct _jc_java_rmi_AlreadyBoundException$fields_struct	_jc_java_rmi_AlreadyBoundException$fields_struct;
typedef const struct _jc_java_rmi_AlreadyBoundException$vmethods	_jc_java_rmi_AlreadyBoundException$vmethods;
typedef const struct _jc_java_rmi_AlreadyBoundException$vtable	_jc_java_rmi_AlreadyBoundException$vtable;
typedef const struct _jc_java_rmi_AlreadyBoundException$vtype	_jc_java_rmi_AlreadyBoundException$vtype;

// Class fields structure
struct _jc_java_rmi_AlreadyBoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_AlreadyBoundException$fields_struct _jc_java_rmi_AlreadyBoundException$class_fields;

// Constructors
extern void _jc_java_rmi_AlreadyBoundException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_AlreadyBoundException$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_AlreadyBoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_AlreadyBoundException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_AlreadyBoundException$vmethods {
};

// Vtable
struct _jc_java_rmi_AlreadyBoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_AlreadyBoundException$vmethods	java_rmi_AlreadyBoundException;
};

// Vtype
struct _jc_java_rmi_AlreadyBoundException$vtype {
	_jc_type			type;
	_jc_java_rmi_AlreadyBoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_AlreadyBoundException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_AlreadyBoundException$refs {
    _jc_java_rmi_AlreadyBoundException$sub_refs	java_rmi_AlreadyBoundException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_AlreadyBoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_AlreadyBoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_AlreadyBoundException$sub_nonrefs	java_rmi_AlreadyBoundException;
};

// Object instance structure
struct _jc_java_rmi_AlreadyBoundException$object {
	_jc_java_rmi_AlreadyBoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_AlreadyBoundException$vtype	*vtype;
	_jc_java_rmi_AlreadyBoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_AlreadyBoundException$vtype _jc_java_rmi_AlreadyBoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_AlreadyBoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_AlreadyBoundException$class_object;

#endif	/* _JC_java_rmi_AlreadyBoundException_H_ */
